@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-# pylint: disable=expression-not-assigned,line-too-long
 """JIRA proxy connector API for code generation."""
 import copy
 import json
@@ -144,8 +143,7 @@ def markdown_table(
             if not laskea.DRY_RUN:
                 print(message, file=sys.stderr)
             return message
-        else:
-            return ''
+        return ''
 
     table = copy.deepcopy(data['rows'])
     columns = list(table[0].keys())  # noqa
@@ -191,11 +189,10 @@ def markdown_list(
             if not laskea.DRY_RUN:
                 print(message, file=sys.stderr)
             return message
-        else:
-            return ''
+        return ''
 
     items = []
-    for slot, record in enumerate(data['rows']):
+    for record in data['rows']:
         k, v = '', ''
         for key, cell in record.items():
             if key.lower() not in ('key', 'summary'):
@@ -211,15 +208,14 @@ def markdown_list(
         xl = tuple(f'{lt} {key} - {summary}' for key, summary in items)
         the_list = '\n'.join(xl) + '\n'
         return the_list.replace('\r', '') if BASE_LF_ONLY else the_list
-    elif list_type == 'dl':
+    if list_type == 'dl':
         # 'Term'
         # ':definition of term'
         #
         xl = tuple(f'{key}\n:{summary}\n' for key, summary in items)
         the_list = '\n'.join(xl) + '\n'
         return the_list.replace('\r', '') if BASE_LF_ONLY else the_list
-    else:
-        return f'Unexpected list type ({list_type}) in markdown_list not in ({("dl", "ol", "ul")})' + '\n'
+    return f'Unexpected list type ({list_type}) in markdown_list not in ({("dl", "ol", "ul")})' + '\n'
 
 
 @no_type_check
@@ -242,11 +238,10 @@ def markdown_heading(
             if not laskea.DRY_RUN:
                 print(message, file=sys.stderr)
             return message
-        else:
-            return ''
+        return ''
 
     items = []
-    for slot, record in enumerate(data['rows']):
+    for record in data['rows']:
         k, v = '', ''
         for key, cell in record.items():
             if key.lower() not in ('key', 'summary'):
@@ -263,19 +258,17 @@ def markdown_heading(
             if not laskea.DRY_RUN:
                 print(message, file=sys.stderr)
             return message.replace('\r', '') if BASE_LF_ONLY else message
-        else:
-            return ''
+        return ''
     level_range = tuple(range(1, 6 + 1))
     if level in level_range:
         heading_token = '#' * level
         xl = tuple(f'{heading_token} {key} - {summary}' for key, summary in items)
         the_heading = '\n'.join(xl)
         return the_heading.replace('\r', '') if BASE_LF_ONLY else the_heading
-    else:
-        message = f'Unexpected level for heading ({level}) in markdown_heading not in ({level_range})'
-        if not laskea.DRY_RUN:
-            print(message, file=sys.stderr)
-        return message
+    message = f'Unexpected level for heading ({level}) in markdown_heading not in ({level_range})'
+    if not laskea.DRY_RUN:
+        print(message, file=sys.stderr)
+    return message
 
 
 @no_type_check
@@ -398,10 +391,10 @@ def parent_children_sections(
 
 
 @no_type_check
-def doc_to_markdown(doc, parent_type_name: str, children_type_name: str) -> str:
+def doc_to_markdown(doc, parent_type_name: str, children_type_name: str) -> str:  # noqa
     """Transform the document content to markdown."""
     md = []
-    for p_key, p_tree in doc.items():
+    for p_tree in doc.values():
         p_head = f'## {p_tree["summary"]}'.strip().strip(LF)
         c_count = len(p_tree['children'])
         c_type_disp = f'{children_type_name}{"" if c_count == 1 else "s"}'
@@ -410,9 +403,9 @@ def doc_to_markdown(doc, parent_type_name: str, children_type_name: str) -> str:
         c_parts = []
         double_pipe, ast_pipe, pipe_ast = '||', '|*', '*|'
         nbsp = '&nbsp;'
-        for c_key, c_data in p_tree['children'].items():
+        for c_data in p_tree['children'].values():
             c_head = f'### {c_data["summary"]}'.strip().strip(LF)
-            c_in = [line for line in c_data['description'].replace(nbsp, ' ').strip().split(LF)]
+            c_in = list(c_data['description'].replace(nbsp, ' ').strip().split(LF))
             c_out = []
             for line in c_in:
                 if line.startswith(double_pipe) or line.startswith(ast_pipe):
@@ -421,9 +414,13 @@ def doc_to_markdown(doc, parent_type_name: str, children_type_name: str) -> str:
                     extra_line = ''
                     if line_s.startswith(double_pipe) and line_s.endswith(double_pipe):
                         line = line.replace(double_pipe, '|')
-                        extra_line = ''.join(c if c == '|' else '-' for c in line).replace('|-', '|:').replace('-|', ' |')
+                        extra_line = (
+                            ''.join(c if c == '|' else '-' for c in line).replace('|-', '|:').replace('-|', ' |')
+                        )
                     elif line_s.startswith(ast_pipe) and line_s.endswith(pipe_ast):
-                        extra_line = ''.join(c if c == '|' else '-' for c in line).replace('|-', '|:').replace('-|', ' |')
+                        extra_line = (
+                            ''.join(c if c == '|' else '-' for c in line).replace('|-', '|:').replace('-|', ' |')
+                        )
                     c_out.append(line)
                     if extra_line:
                         c_out.append(extra_line)
